@@ -1,10 +1,11 @@
-#!/usr/bin/env python
-# -*- coding: UTF-8 -*-
+# -*- coding: utf-8 -*-
 """ Environment Variable Utility Methods """
 
 
 import os
 
+from typing import List
+
 
 class EnvIO(object):
     """ Environment Variable Utility Methods """
@@ -22,20 +23,21 @@ class EnvIO(object):
         return env_var in os.environ and len(os.environ[env_var])
 
     @staticmethod
-    def float_or_exception(env_var: str) -> float:
+    def float_or_exception(*args) -> float:
         """Retrieve Environment Variable by Name or throw exception
 
         Args:
-            env_var (str): the Environment Variable name
+            args (list): a list of Environment Variable names
 
         Raises:
-            ValueError: the Environment Variable was not found
+            ValueError: none of the Environment Variables were not found
 
         Returns:
-            float: the Environment Variable value
+            str: the first Environment Variable value to be found
         """
-        if EnvIO.exists(env_var):
-            return EnvIO.as_float(env_var)
+        for env_var in args:
+            if EnvIO.exists(env_var):
+                return EnvIO.as_float(env_var)
         raise ValueError(env_var)
 
     @staticmethod
@@ -52,29 +54,30 @@ class EnvIO(object):
         """
         if EnvIO.exists(env_var):
             return EnvIO.as_float(env_var)
-        raise default
+        return default
 
     @staticmethod
-    def int_or_exception(env_var: str) -> int:
+    def int_or_exception(*args) -> int:
         """Retrieve Environment Variable by Name or throw exception
 
         Args:
-            env_var (str): the Environment Variable name
+            args (list): a list of Environment Variable names
 
         Raises:
-            ValueError: the Environment Variable was not found
+            ValueError: none of the Environment Variables were not found
 
         Returns:
-            int: the Environment Variable value
+            str: the first Environment Variable value to be found
         """
-        if EnvIO.exists(env_var):
-            return EnvIO.as_int(env_var)
+        for env_var in args:
+            if EnvIO.exists(env_var):
+                return EnvIO.as_int(env_var)
         raise ValueError(env_var)
 
     @staticmethod
     def int_or_default(env_var: str,
                        default: int) -> int:
-        """Retrieve Environment Variable by Name or return default
+        """Retrieve Environment Variable by Name or return a default value
 
         Args:
             env_var (str): the Environment Variable name
@@ -91,7 +94,7 @@ class EnvIO(object):
     @staticmethod
     def str_or_default(env_var: str,
                        default: str) -> str:
-        """Retrieve Environment Variable by Name or return default
+        """Retrieve Environment Variable by Name or return a default value
 
         Args:
             env_var (str): the Environment Variable name
@@ -103,86 +106,92 @@ class EnvIO(object):
         return os.environ.get(env_var, default)
 
     @staticmethod
-    def str_or_exception(env_var: str) -> str:
+    def str_or_exception(*args) -> str:
         """Retrieve Environment Variable by Name or throw exception
 
         Args:
-            env_var (str): the Environment Variable name
+            args (list): a list of Environment Variable names
 
         Raises:
-            ValueError: the Environment Variable was not found
+            ValueError: none of the Environment Variables were not found
 
         Returns:
-            str: the Environment Variable value
+            str: the first Environment Variable value to be found
         """
-        if EnvIO.exists(env_var):
-            return EnvIO.as_str(env_var)
-        raise ValueError(env_var)
+        for env_var in args:
+            if EnvIO.exists(env_var):
+                return EnvIO.as_str(env_var)
+
+        raise ValueError(args)
 
     @staticmethod
-    def as_list(env_var: str,
+    def as_list(*args,
                 lower: bool = True) -> list:
         """Retrieve Environment Variable as a tokenized value to list
 
         Args:
-            env_var (str): the Environment Variable name
+            args (str): a list of one-or-more Environment Variable names
 
         Returns:
             str or None: a list representation of the values
         """
-        if env_var in os.environ:
-            values = [x.strip() for x in os.environ[env_var].split(',')]
-            values = [x for x in values if x and len(x)]
-            if lower:
-                values = [x.lower() for x in values]
-            return values
+        for env_var in args:
+            if env_var in os.environ:
+                values = [x.strip() for x in os.environ[env_var].split(',')]
+                values = [x for x in values if x and len(x)]
+                if lower:
+                    values = [x.lower() for x in values]
+                return values
 
         return []
 
     @staticmethod
-    def as_str(env_var: str) -> str or None:
+    def as_str(*args) -> str or None:
         """Retrieve Environment Variable as a string value
 
         Args:
-            env_var (str): the Environment Variable name
+            args (str): a list of one-or-more Environment Variable names
 
         Returns:
             str or None: a String representation of the value
         """
-        if env_var in os.environ:
-            return str(os.environ[env_var])
+        for env_var in args:
+            if env_var in os.environ:
+                return str(os.environ[env_var])
 
     @staticmethod
-    def as_int(env_var: str) -> int or None:
+    def as_int(*args) -> int or None:
         """Retrieve Environment Variable as an int value
 
         Args:
-            env_var (str): the Environment Variable name
+            args (str): a list of one-or-more Environment Variable names
 
         Returns:
             str or None: an int representation of the value
         """
-        if env_var in os.environ:
-            try:
-                return int(os.environ[env_var])
-            except ValueError:
-                pass
+        for env_var in args:
+            if env_var in os.environ:
+                try:
+                    return int(os.environ[env_var])
+                except ValueError:
+                    pass
 
     @staticmethod
-    def as_float(env_var: str) -> float or None:
+    def as_float(*args) -> float or None:
         """Retrieve Environment Variable as a float value
 
         Args:
-            env_var (str): the Environment Variable name
+            args (str): a list of one-or-more Environment Variable names
 
         Returns:
             str or None: a float representation of the value
         """
-        if env_var in os.environ:
-            try:
-                return float(os.environ[env_var])
-            except ValueError:
-                pass
+        for env_var in args:
+            if env_var in os.environ:
+                try:
+                    return float(os.environ[env_var])
+                except ValueError:
+                    pass
 
     @staticmethod
     def is_true(env_var: str) -> bool:
@@ -194,11 +203,11 @@ class EnvIO(object):
 
     @staticmethod
     def set_true(env_var: str) -> None:
-        os.environ[env_var] = True
+        os.environ[env_var] = str(True)
 
     @staticmethod
     def set_false(env_var: str) -> None:
-        os.environ[env_var] = False
+        os.environ[env_var] = str(False)
 
     @staticmethod
     def exists_as_true(env_var: str) -> bool:
